LevelDbError

Enum LevelDbError 

#[non_exhaustive]
pub enum LevelDbError { Io { operation: &'static str, path: Option<PathBuf>, source: Error, }, Corruption { path: Option<PathBuf>, message: String, }, InvalidArgument { message: String, }, Unsupported { feature: &'static str, message: String, }, Compression { codec: &'static str, message: String, }, Cancelled, ReadOnly, AlreadyExists { path: PathBuf, }, NotFound { path: PathBuf, }, LockPoisoned { operation: &'static str, }, Join { message: String, }, }
Errors returned while opening, reading, writing, or repairing a database.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io

Filesystem or OS I/O failure.

Fields

operation: &'static str

Operation being performed when the error occurred.

path: Option<PathBuf>

Filesystem path involved in the operation, when known.

source: Error

Underlying operating-system error.



Corruption

On-disk data was malformed or failed validation.

Fields

path: Option<PathBuf>

Path to the file whose bytes failed validation, when known.

message: String

Human-readable corruption reason.



InvalidArgument

Caller supplied invalid options or input.

Fields

message: String

Human-readable validation failure.



Unsupported

The requested feature is disabled or not implemented.

Fields

feature: &'static str

Feature, codec, or behavior that is unavailable.

message: String

Human-readable explanation.



Compression

Compression or decompression failed.

Fields

codec: &'static str

Codec or table compression family being processed.

message: String

Human-readable codec error.



Cancelled

Scan cancelled through crate::ScanCancelFlag.



ReadOnly

A mutating operation was requested on a read-only database.



AlreadyExists

OpenOptions::error_if_exists rejected an existing database.

Fields

path: PathBuf

Existing database directory.



NotFound

The requested database or required metadata file was missing.

Fields

path: PathBuf

Missing database directory or metadata file.



LockPoisoned

An internal lock was poisoned.

Fields

operation: &'static str

Locking operation that observed poisoning.



Join

A blocking task failed to join in the optional async wrapper.

Fields

message: String

Human-readable join failure.

Implementations

Source

impl LevelDbError

pub const fn kind(&self) -> ErrorKind

Returns the stable category of this error.

pub fn path(&self) -> Option<&Path>

Returns the filesystem path associated with this error, when known.