#[non_exhaustive]pub enum LevelDbError {
Io {
operation: &'static str,
path: Option<PathBuf>,
source: Error,
},
Corruption {
path: Option<PathBuf>,
message: String,
},
InvalidArgument {
message: String,
},
Unsupported {
feature: &'static str,
message: String,
},
Compression {
codec: &'static str,
message: String,
},
Cancelled,
ReadOnly,
AlreadyExists {
path: PathBuf,
},
NotFound {
path: PathBuf,
},
LockPoisoned {
operation: &'static str,
},
Join {
message: String,
},
}Expand description
Errors returned while opening, reading, writing, or repairing a database.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
Filesystem or OS I/O failure.
Fields
Corruption
On-disk data was malformed or failed validation.
Fields
InvalidArgument
Caller supplied invalid options or input.
Unsupported
The requested feature is disabled or not implemented.
Fields
Compression
Compression or decompression failed.
Fields
Cancelled
Scan cancelled through crate::ScanCancelFlag.
ReadOnly
A mutating operation was requested on a read-only database.
AlreadyExists
OpenOptions::error_if_exists rejected an existing database.
NotFound
The requested database or required metadata file was missing.
LockPoisoned
An internal lock was poisoned.
Join
A blocking task failed to join in the optional async wrapper.
Implementations