pub enum ThreadingOptions {
Auto,
Fixed(usize),
Single,
}Expand description
How many worker threads a table-parallel scan may use.
Variants
Auto
Use available parallelism, capped by the number of table files.
Fixed(usize)
Use an explicit worker count in 1..=512.
Single
Force one worker.
Implementations
Sourceimpl ThreadingOptions
impl ThreadingOptions
Sourcepub fn resolve(self, work_items: usize) -> usize
pub fn resolve(self, work_items: usize) -> usize
Resolves this setting to a concrete worker count.
Sourcepub fn resolve_unchecked(self, work_items: usize) -> usize
pub fn resolve_unchecked(self, work_items: usize) -> usize
Resolves this setting without returning validation errors.
Sourcepub fn resolve_checked(self, work_items: usize) -> Result<usize>
pub fn resolve_checked(self, work_items: usize) -> Result<usize>
Resolves this setting and rejects invalid fixed worker counts.
Errors
Returns LevelDbError::InvalidArgument when Fixed(0) or a value
above 512 is requested.